@@ -2,6 +2,8 @@
 
 pub(crate) mod affine;
 mod field;
+#[cfg(feature = "hash2curve")]
+mod hash2curve;
 mod mul;
 pub(crate) mod projective;
 pub(crate) mod scalar;
