@@ -83,11 +83,6 @@ pub use self::{sign::SigningKey, verify::VerifyingKey};
 
 use crate::Secp256k1;
 
-#[cfg(feature = "ecdsa")]
-use crate::NonZeroScalar;
-#[cfg(feature = "ecdsa")]
-use elliptic_curve::generic_array::GenericArray;
-
 /// ECDSA/secp256k1 signature (fixed-size)
 pub type Signature = ecdsa_core::Signature<Secp256k1>;
 
@@ -100,25 +95,11 @@ impl ecdsa_core::hazmat::DigestPrimitive for Secp256k1 {
     type Digest = sha2::Sha256;
 }
 
-/// Validate that the scalars of an ECDSA signature are modulo the order
-#[cfg(feature = "ecdsa")]
-fn check_scalars(signature: &Signature) -> Result<(), Error> {
-    let (r_bytes, s_bytes) = signature.as_ref().split_at(32);
-    let r_valid = NonZeroScalar::from_repr(GenericArray::clone_from_slice(r_bytes)).is_some();
-    let s_valid = NonZeroScalar::from_repr(GenericArray::clone_from_slice(s_bytes)).is_some();
-
-    if r_valid && s_valid {
-        Ok(())
-    } else {
-        Err(Error::new())
-    }
-}
-
 #[cfg(all(test, feature = "ecdsa", feature = "arithmetic"))]
 mod tests {
     mod wycheproof {
-        use crate::Secp256k1;
-        use ecdsa_core::{elliptic_curve::sec1::EncodedPoint, signature::Verifier, Signature};
+        use crate::{EncodedPoint, Secp256k1};
+        use ecdsa_core::{signature::Verifier, Signature};
 
         #[test]
         fn wycheproof() {
@@ -154,19 +135,17 @@ mod tests {
             ) -> Option<&'static str> {
                 let x = element_from_padded_slice::<Secp256k1>(wx);
                 let y = element_from_padded_slice::<Secp256k1>(wy);
-                let q_encoded: EncodedPoint<Secp256k1> =
+                let q_encoded =
                     EncodedPoint::from_affine_coordinates(&x, &y, /* compress= */ false);
                 let verifying_key =
                     ecdsa_core::VerifyingKey::from_encoded_point(&q_encoded).unwrap();
 
-                let mut sig = match Signature::<Secp256k1>::from_der(sig) {
-                    Ok(s) => s,
+                let sig = match Signature::<Secp256k1>::from_der(sig) {
+                    Ok(s) => s.normalize_s().unwrap_or(s),
                     Err(_) if !pass => return None,
                     Err(_) => return Some("failed to parse signature ASN.1"),
                 };
 
-                sig.normalize_s().unwrap();
-
                 match verifying_key.verify(msg, &sig) {
                     Ok(_) if pass => None,
                     Ok(_) => Some("signature verify unexpectedly succeeded"),
